notelike

package
v0.0.0-...-8e868a9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the notelike type in the database.
	Label = "note_like"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// EdgeNote holds the string denoting the note edge name in mutations.
	EdgeNote = "note"
	// Table holds the table name of the notelike in the database.
	Table = "note_likes"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "note_likes"
	// UserInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	UserInverseTable = "users"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "user_note_likes"
	// NoteTable is the table that holds the note relation/edge.
	NoteTable = "note_likes"
	// NoteInverseTable is the table name for the Note entity.
	// It exists in this package in order to avoid circular dependency with the "note" package.
	NoteInverseTable = "notes"
	// NoteColumn is the table column denoting the note relation/edge.
	NoteColumn = "note_likes"
)

Variables

var Columns = []string{
	FieldID,
	FieldCreatedAt,
}

Columns holds all SQL columns for notelike fields.

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
)
var ForeignKeys = []string{
	"note_likes",
	"user_note_likes",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "note_likes" table and are not defined as standalone fields in the schema.

Functions

func And

func And(predicates ...predicate.NoteLike) predicate.NoteLike

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.NoteLike

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.NoteLike

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.NoteLike

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.NoteLike

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.NoteLike

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.NoteLike

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.NoteLike

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.NoteLike

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.NoteLike

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func HasNote

func HasNote() predicate.NoteLike

HasNote applies the HasEdge predicate on the "note" edge.

func HasNoteWith

func HasNoteWith(preds ...predicate.Note) predicate.NoteLike

HasNoteWith applies the HasEdge predicate on the "note" edge with a given conditions (other predicates).

func HasUser

func HasUser() predicate.NoteLike

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.User) predicate.NoteLike

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.NoteLike

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.NoteLike

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.NoteLike

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.NoteLike

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.NoteLike

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.NoteLike

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.NoteLike

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.NoteLike

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.NoteLike

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.NoteLike) predicate.NoteLike

Or groups predicates with the OR operator between them.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the NoteLike queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByNoteField

func ByNoteField(field string, opts ...sql.OrderTermOption) OrderOption

ByNoteField orders the results by note field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

Jump to