noterepost

package
v0.0.0-...-8e868a9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the noterepost type in the database.
	Label = "note_repost"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldComment holds the string denoting the comment field in the database.
	FieldComment = "comment"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// EdgeNote holds the string denoting the note edge name in mutations.
	EdgeNote = "note"
	// Table holds the table name of the noterepost in the database.
	Table = "note_reposts"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "note_reposts"
	// UserInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	UserInverseTable = "users"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "user_note_reposts"
	// NoteTable is the table that holds the note relation/edge.
	NoteTable = "note_reposts"
	// NoteInverseTable is the table name for the Note entity.
	// It exists in this package in order to avoid circular dependency with the "note" package.
	NoteInverseTable = "notes"
	// NoteColumn is the table column denoting the note relation/edge.
	NoteColumn = "note_reposts"
)

Variables

Columns holds all SQL columns for noterepost fields.

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
)
var ForeignKeys = []string{
	"note_reposts",
	"user_note_reposts",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "note_reposts" table and are not defined as standalone fields in the schema.

Functions

func And

func And(predicates ...predicate.NoteRepost) predicate.NoteRepost

And groups predicates with the AND operator between them.

func Comment

func Comment(v string) predicate.NoteRepost

Comment applies equality check predicate on the "comment" field. It's identical to CommentEQ.

func CommentContains

func CommentContains(v string) predicate.NoteRepost

CommentContains applies the Contains predicate on the "comment" field.

func CommentContainsFold

func CommentContainsFold(v string) predicate.NoteRepost

CommentContainsFold applies the ContainsFold predicate on the "comment" field.

func CommentEQ

func CommentEQ(v string) predicate.NoteRepost

CommentEQ applies the EQ predicate on the "comment" field.

func CommentEqualFold

func CommentEqualFold(v string) predicate.NoteRepost

CommentEqualFold applies the EqualFold predicate on the "comment" field.

func CommentGT

func CommentGT(v string) predicate.NoteRepost

CommentGT applies the GT predicate on the "comment" field.

func CommentGTE

func CommentGTE(v string) predicate.NoteRepost

CommentGTE applies the GTE predicate on the "comment" field.

func CommentHasPrefix

func CommentHasPrefix(v string) predicate.NoteRepost

CommentHasPrefix applies the HasPrefix predicate on the "comment" field.

func CommentHasSuffix

func CommentHasSuffix(v string) predicate.NoteRepost

CommentHasSuffix applies the HasSuffix predicate on the "comment" field.

func CommentIn

func CommentIn(vs ...string) predicate.NoteRepost

CommentIn applies the In predicate on the "comment" field.

func CommentIsNil

func CommentIsNil() predicate.NoteRepost

CommentIsNil applies the IsNil predicate on the "comment" field.

func CommentLT

func CommentLT(v string) predicate.NoteRepost

CommentLT applies the LT predicate on the "comment" field.

func CommentLTE

func CommentLTE(v string) predicate.NoteRepost

CommentLTE applies the LTE predicate on the "comment" field.

func CommentNEQ

func CommentNEQ(v string) predicate.NoteRepost

CommentNEQ applies the NEQ predicate on the "comment" field.

func CommentNotIn

func CommentNotIn(vs ...string) predicate.NoteRepost

CommentNotIn applies the NotIn predicate on the "comment" field.

func CommentNotNil

func CommentNotNil() predicate.NoteRepost

CommentNotNil applies the NotNil predicate on the "comment" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.NoteRepost

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.NoteRepost

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.NoteRepost

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.NoteRepost

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.NoteRepost

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.NoteRepost

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.NoteRepost

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.NoteRepost

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.NoteRepost

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func HasNote

func HasNote() predicate.NoteRepost

HasNote applies the HasEdge predicate on the "note" edge.

func HasNoteWith

func HasNoteWith(preds ...predicate.Note) predicate.NoteRepost

HasNoteWith applies the HasEdge predicate on the "note" edge with a given conditions (other predicates).

func HasUser

func HasUser() predicate.NoteRepost

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.User) predicate.NoteRepost

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.NoteRepost

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.NoteRepost

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.NoteRepost

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.NoteRepost

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.NoteRepost

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.NoteRepost

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.NoteRepost

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.NoteRepost

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.NoteRepost

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.NoteRepost) predicate.NoteRepost

Or groups predicates with the OR operator between them.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the NoteRepost queries.

func ByComment

func ByComment(opts ...sql.OrderTermOption) OrderOption

ByComment orders the results by the comment field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByNoteField

func ByNoteField(field string, opts ...sql.OrderTermOption) OrderOption

ByNoteField orders the results by note field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

Jump to