Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.NoteLike) predicate.NoteLike
- func CreatedAt(v time.Time) predicate.NoteLike
- func CreatedAtEQ(v time.Time) predicate.NoteLike
- func CreatedAtGT(v time.Time) predicate.NoteLike
- func CreatedAtGTE(v time.Time) predicate.NoteLike
- func CreatedAtIn(vs ...time.Time) predicate.NoteLike
- func CreatedAtLT(v time.Time) predicate.NoteLike
- func CreatedAtLTE(v time.Time) predicate.NoteLike
- func CreatedAtNEQ(v time.Time) predicate.NoteLike
- func CreatedAtNotIn(vs ...time.Time) predicate.NoteLike
- func HasNote() predicate.NoteLike
- func HasNoteWith(preds ...predicate.Note) predicate.NoteLike
- func HasUser() predicate.NoteLike
- func HasUserWith(preds ...predicate.User) predicate.NoteLike
- func ID(id int) predicate.NoteLike
- func IDEQ(id int) predicate.NoteLike
- func IDGT(id int) predicate.NoteLike
- func IDGTE(id int) predicate.NoteLike
- func IDIn(ids ...int) predicate.NoteLike
- func IDLT(id int) predicate.NoteLike
- func IDLTE(id int) predicate.NoteLike
- func IDNEQ(id int) predicate.NoteLike
- func IDNotIn(ids ...int) predicate.NoteLike
- func Not(p predicate.NoteLike) predicate.NoteLike
- func Or(predicates ...predicate.NoteLike) predicate.NoteLike
- func ValidColumn(column string) bool
- type OrderOption
Constants ¶
const ( // Label holds the string label denoting the notelike type in the database. Label = "note_like" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // EdgeUser holds the string denoting the user edge name in mutations. EdgeUser = "user" // EdgeNote holds the string denoting the note edge name in mutations. EdgeNote = "note" // Table holds the table name of the notelike in the database. Table = "note_likes" // UserTable is the table that holds the user relation/edge. UserTable = "note_likes" // UserInverseTable is the table name for the User entity. // It exists in this package in order to avoid circular dependency with the "user" package. UserInverseTable = "users" // UserColumn is the table column denoting the user relation/edge. UserColumn = "user_note_likes" // NoteTable is the table that holds the note relation/edge. NoteTable = "note_likes" // NoteInverseTable is the table name for the Note entity. // It exists in this package in order to avoid circular dependency with the "note" package. NoteInverseTable = "notes" // NoteColumn is the table column denoting the note relation/edge. NoteColumn = "note_likes" )
Variables ¶
var Columns = []string{ FieldID, FieldCreatedAt, }
Columns holds all SQL columns for notelike fields.
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time )
var ForeignKeys = []string{
"note_likes",
"user_note_likes",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "note_likes" table and are not defined as standalone fields in the schema.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasNoteWith ¶
HasNoteWith applies the HasEdge predicate on the "note" edge with a given conditions (other predicates).
func HasUserWith ¶
HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the NoteLike queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByNoteField ¶
func ByNoteField(field string, opts ...sql.OrderTermOption) OrderOption
ByNoteField orders the results by note field.
func ByUserField ¶
func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption
ByUserField orders the results by user field.